==> blancoMailCore-0.6.1-src.zip: src/blanco/mail/core/BlancoMailSettingFactory.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.mail.core;

import blanco.mail.core.resourcebundle.BlancoMailSettingResourceBundle;
import blanco.mail.core.valueobject.BlancoMailSetting;

/**
 * BlancoMailSetting̃CX^X́ÃNX擾ĂB
 *
 * o[IuWFNg[BlancoMailSetting]̃CX^XK؂ȃftHgltŎ擾邽߂̃NXB
 */
public class BlancoMailSettingFactory {
    /**
     * RXgN^͉B܂B
     */
    private BlancoMailSettingFactory() {
    }

    /**
     * o[IuWFNg[BlancoMailSetting]̃CX^X擾܂B
     *
     * \[Xoh(ꖼ:BlancoMailSetting, NX:BlancoMailSettingResourceBundle)ftHgl̓ǂݍ݂݂܂B
     *
     * @return ftHglς݂[BlancoMailSetting]o[IuWFNgB
     */
    public static BlancoMailSetting getInstance() {
        // ̃\bh̎sʂƂȂo[IuWFNgCX^XB
        final BlancoMailSetting result = new BlancoMailSetting();

        // o[IuWFNgɐݒ肷ftHgl̂߂̃f[^\[XCX^XB
        final BlancoMailSettingResourceBundle bundle = new BlancoMailSettingResourceBundle();

        // tB[h [SEND_HOST]
        if (bundle.getSendHost() != null && bundle.getSendHost().length() > 0) {
            result.setSendHost(bundle.getSendHost());
        }

        // tB[h [SEND_PORT]
        if (bundle.getSendPort() != null && bundle.getSendPort().length() > 0) {
            try {
                result.setSendPort(Integer.parseInt(bundle.getSendPort()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [SEND_USE_SSL]
        if (bundle.getSendUseSsl() != null && bundle.getSendUseSsl().length() > 0) {
            result.setSendUseSsl("true".equals(bundle.getSendUseSsl()));
        }

        // tB[h [SEND_USER_NAME]
        if (bundle.getSendUserName() != null && bundle.getSendUserName().length() > 0) {
            result.setSendUserName(bundle.getSendUserName());
        }

        // tB[h [SEND_PASSWORD]
        if (bundle.getSendPassword() != null && bundle.getSendPassword().length() > 0) {
            result.setSendPassword(bundle.getSendPassword());
        }

        // tB[h [SEND_PROTOCOL]
        if (bundle.getSendProtocol() != null && bundle.getSendProtocol().length() > 0) {
            result.setSendProtocol(bundle.getSendProtocol());
        }

        // tB[h [SEND_SMTP_AUTH]
        if (bundle.getSendSmtpAuth() != null && bundle.getSendSmtpAuth().length() > 0) {
            result.setSendSmtpAuth("true".equals(bundle.getSendSmtpAuth()));
        }

        // tB[h [SEND_LOCAL_HOST]
        if (bundle.getSendLocalHost() != null && bundle.getSendLocalHost().length() > 0) {
            result.setSendLocalHost(bundle.getSendLocalHost());
        }

        // tB[h [RECEIVE_HOST]
        if (bundle.getReceiveHost() != null && bundle.getReceiveHost().length() > 0) {
            result.setReceiveHost(bundle.getReceiveHost());
        }

        // tB[h [RECEIVE_PORT]
        if (bundle.getReceivePort() != null && bundle.getReceivePort().length() > 0) {
            try {
                result.setReceivePort(Integer.parseInt(bundle.getReceivePort()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [RECEIVE_USE_SSL]
        if (bundle.getReceiveUseSsl() != null && bundle.getReceiveUseSsl().length() > 0) {
            result.setReceiveUseSsl("true".equals(bundle.getReceiveUseSsl()));
        }

        // tB[h [RECEIVE_USER_NAME]
        if (bundle.getReceiveUserName() != null && bundle.getReceiveUserName().length() > 0) {
            result.setReceiveUserName(bundle.getReceiveUserName());
        }

        // tB[h [RECEIVE_PASSWORD]
        if (bundle.getReceivePassword() != null && bundle.getReceivePassword().length() > 0) {
            result.setReceivePassword(bundle.getReceivePassword());
        }

        // tB[h [RECEIVE_PROTOCOL]
        if (bundle.getReceiveProtocol() != null && bundle.getReceiveProtocol().length() > 0) {
            result.setReceiveProtocol(bundle.getReceiveProtocol());
        }

        // tB[h [RECEIVE_POP3_APOP]
        if (bundle.getReceivePop3Apop() != null && bundle.getReceivePop3Apop().length() > 0) {
            result.setReceivePop3Apop("true".equals(bundle.getReceivePop3Apop()));
        }

        // tB[h [MAIL_CONNECTION_TIMEOUT]
        if (bundle.getMailConnectionTimeout() != null && bundle.getMailConnectionTimeout().length() > 0) {
            try {
                result.setMailConnectionTimeout(Integer.parseInt(bundle.getMailConnectionTimeout()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [MAIL_TIMEOUT]
        if (bundle.getMailTimeout() != null && bundle.getMailTimeout().length() > 0) {
            try {
                result.setMailTimeout(Integer.parseInt(bundle.getMailTimeout()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [SESSION_LOG_DIRECTORY_ERROR]
        if (bundle.getSessionLogDirectoryError() != null && bundle.getSessionLogDirectoryError().length() > 0) {
            result.setSessionLogDirectoryError(bundle.getSessionLogDirectoryError());
        }

        // tB[h [SESSION_LOG_DIRECTORY_SUCCESS]
        if (bundle.getSessionLogDirectorySuccess() != null && bundle.getSessionLogDirectorySuccess().length() > 0) {
            result.setSessionLogDirectorySuccess(bundle.getSessionLogDirectorySuccess());
        }

        // tB[h [SESSION_LOG_OUTPUT_WITH_NO_RECEIVE_PROCESS]
        if (bundle.getSessionLogOutputWithNoReceiveProcess() != null && bundle.getSessionLogOutputWithNoReceiveProcess().length() > 0) {
            result.setSessionLogOutputWithNoReceiveProcess("true".equals(bundle.getSessionLogOutputWithNoReceiveProcess()));
        }

        // tB[h [SOCKETFACTORY_CLASS]
        if (bundle.getSocketfactoryClass() != null && bundle.getSocketfactoryClass().length() > 0) {
            result.setSocketfactoryClass(bundle.getSocketfactoryClass());
        }

        // tB[h [SOCKETFACTORY_FALLBACK]
        if (bundle.getSocketfactoryFallback() != null && bundle.getSocketfactoryFallback().length() > 0) {
            result.setSocketfactoryFallback("true".equals(bundle.getSocketfactoryFallback()));
        }

        // tB[h [TEST_MODE]
        if (bundle.getTestMode() != null && bundle.getTestMode().length() > 0) {
            result.setTestMode("true".equals(bundle.getTestMode()));
        }

        // tB[h [TEST_MODE_LOG_DIRECTORY_SEND]
        if (bundle.getTestModeLogDirectorySend() != null && bundle.getTestModeLogDirectorySend().length() > 0) {
            result.setTestModeLogDirectorySend(bundle.getTestModeLogDirectorySend());
        }

        // tB[h [TEST_MODE_LOG_DIRECTORY_RECEIVE]
        if (bundle.getTestModeLogDirectoryReceive() != null && bundle.getTestModeLogDirectoryReceive().length() > 0) {
            result.setTestModeLogDirectoryReceive(bundle.getTestModeLogDirectoryReceive());
        }

        // tB[h [SEND_MAILER_NAME]
        if (bundle.getSendMailerName() != null && bundle.getSendMailerName().length() > 0) {
            result.setSendMailerName(bundle.getSendMailerName());
        }

        // tB[h [SEND_ENCODING]
        if (bundle.getSendEncoding() != null && bundle.getSendEncoding().length() > 0) {
            result.setSendEncoding(bundle.getSendEncoding());
        }

        // tB[h [SEND_FORTH_CONTENT_TRANSFER_ENCODING_7BIT]
        if (bundle.getSendForthContentTransferEncoding7bit() != null && bundle.getSendForthContentTransferEncoding7bit().length() > 0) {
            result.setSendForthContentTransferEncoding7bit("true".equals(bundle.getSendForthContentTransferEncoding7bit()));
        }

        // tB[h [SEND_FORTH_NEWLINE_AFTER_MESSAGE_TEXT]
        if (bundle.getSendForthNewlineAfterMessageText() != null && bundle.getSendForthNewlineAfterMessageText().length() > 0) {
            result.setSendForthNewlineAfterMessageText("true".equals(bundle.getSendForthNewlineAfterMessageText()));
        }

        // tB[h [SEND_USE_FROM_ADDRESS_AS_MESSAGE_ID]
        if (bundle.getSendUseFromAddressAsMessageId() != null && bundle.getSendUseFromAddressAsMessageId().length() > 0) {
            result.setSendUseFromAddressAsMessageId("true".equals(bundle.getSendUseFromAddressAsMessageId()));
        }

        // tB[h [SEND_MAX_RECIPIENT_ADDR_TO]
        if (bundle.getSendMaxRecipientAddrTo() != null && bundle.getSendMaxRecipientAddrTo().length() > 0) {
            try {
                result.setSendMaxRecipientAddrTo(Integer.parseInt(bundle.getSendMaxRecipientAddrTo()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [SEND_MAX_RECIPIENT_ADDR_CC]
        if (bundle.getSendMaxRecipientAddrCc() != null && bundle.getSendMaxRecipientAddrCc().length() > 0) {
            try {
                result.setSendMaxRecipientAddrCc(Integer.parseInt(bundle.getSendMaxRecipientAddrCc()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [SEND_MAX_TOTAL_ATTACHMENT_SIZE]
        if (bundle.getSendMaxTotalAttachmentSize() != null && bundle.getSendMaxTotalAttachmentSize().length() > 0) {
            try {
                result.setSendMaxTotalAttachmentSize(Integer.parseInt(bundle.getSendMaxTotalAttachmentSize()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [RECEIVE_MAX_MESSAGE_SIZE]
        if (bundle.getReceiveMaxMessageSize() != null && bundle.getReceiveMaxMessageSize().length() > 0) {
            try {
                result.setReceiveMaxMessageSize(Integer.parseInt(bundle.getReceiveMaxMessageSize()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [RECEIVE_FILTER_BY_SUBJECT]
        if (bundle.getReceiveFilterBySubject() != null && bundle.getReceiveFilterBySubject().length() > 0) {
            result.setReceiveFilterBySubject(bundle.getReceiveFilterBySubject());
        }

        return result;
    }
}

==> blancoMailCore-0.7.1-src.zip: src/blanco/mail/core/BlancoMailSettingFactory.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.mail.core;

import blanco.mail.core.resourcebundle.BlancoMailSettingResourceBundle;
import blanco.mail.core.valueobject.BlancoMailSetting;

/**
 * BlancoMailSetting̃CX^X́ÃNX擾ĂB
 *
 * o[IuWFNg[BlancoMailSetting]̃CX^XK؂ȃftHgltŎ擾邽߂̃NXB
 */
public class BlancoMailSettingFactory {
    /**
     * RXgN^͉B܂B
     */
    private BlancoMailSettingFactory() {
    }

    /**
     * o[IuWFNg[BlancoMailSetting]̃CX^X擾܂B
     *
     * \[Xoh(ꖼ:BlancoMailSetting, NX:BlancoMailSettingResourceBundle)ftHgl̓ǂݍ݂݂܂B
     *
     * @return ftHglς݂[BlancoMailSetting]o[IuWFNgB
     */
    public static BlancoMailSetting getInstance() {
        // ̃\bh̎sʂƂȂo[IuWFNgCX^XB
        final BlancoMailSetting result = new BlancoMailSetting();

        // o[IuWFNgɐݒ肷ftHgl̂߂̃f[^\[XCX^XB
        final BlancoMailSettingResourceBundle bundle = new BlancoMailSettingResourceBundle();

        // tB[h [SEND_HOST]
        if (bundle.getSendHost() != null && bundle.getSendHost().length() > 0) {
            result.setSendHost(bundle.getSendHost());
        }

        // tB[h [SEND_PORT]
        if (bundle.getSendPort() != null && bundle.getSendPort().length() > 0) {
            try {
                result.setSendPort(Integer.parseInt(bundle.getSendPort()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [SEND_USE_SSL]
        if (bundle.getSendUseSsl() != null && bundle.getSendUseSsl().length() > 0) {
            result.setSendUseSsl("true".equals(bundle.getSendUseSsl()));
        }

        // tB[h [SEND_USER_NAME]
        if (bundle.getSendUserName() != null && bundle.getSendUserName().length() > 0) {
            result.setSendUserName(bundle.getSendUserName());
        }

        // tB[h [SEND_PASSWORD]
        if (bundle.getSendPassword() != null && bundle.getSendPassword().length() > 0) {
            result.setSendPassword(bundle.getSendPassword());
        }

        // tB[h [SEND_PROTOCOL]
        if (bundle.getSendProtocol() != null && bundle.getSendProtocol().length() > 0) {
            result.setSendProtocol(bundle.getSendProtocol());
        }

        // tB[h [SEND_SMTP_AUTH]
        if (bundle.getSendSmtpAuth() != null && bundle.getSendSmtpAuth().length() > 0) {
            result.setSendSmtpAuth("true".equals(bundle.getSendSmtpAuth()));
        }

        // tB[h [SEND_LOCAL_HOST]
        if (bundle.getSendLocalHost() != null && bundle.getSendLocalHost().length() > 0) {
            result.setSendLocalHost(bundle.getSendLocalHost());
        }

        // tB[h [RECEIVE_HOST]
        if (bundle.getReceiveHost() != null && bundle.getReceiveHost().length() > 0) {
            result.setReceiveHost(bundle.getReceiveHost());
        }

        // tB[h [RECEIVE_PORT]
        if (bundle.getReceivePort() != null && bundle.getReceivePort().length() > 0) {
            try {
                result.setReceivePort(Integer.parseInt(bundle.getReceivePort()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [RECEIVE_USE_SSL]
        if (bundle.getReceiveUseSsl() != null && bundle.getReceiveUseSsl().length() > 0) {
            result.setReceiveUseSsl("true".equals(bundle.getReceiveUseSsl()));
        }

        // tB[h [RECEIVE_USER_NAME]
        if (bundle.getReceiveUserName() != null && bundle.getReceiveUserName().length() > 0) {
            result.setReceiveUserName(bundle.getReceiveUserName());
        }

        // tB[h [RECEIVE_PASSWORD]
        if (bundle.getReceivePassword() != null && bundle.getReceivePassword().length() > 0) {
            result.setReceivePassword(bundle.getReceivePassword());
        }

        // tB[h [RECEIVE_PROTOCOL]
        if (bundle.getReceiveProtocol() != null && bundle.getReceiveProtocol().length() > 0) {
            result.setReceiveProtocol(bundle.getReceiveProtocol());
        }

        // tB[h [RECEIVE_POP3_APOP]
        if (bundle.getReceivePop3Apop() != null && bundle.getReceivePop3Apop().length() > 0) {
            result.setReceivePop3Apop("true".equals(bundle.getReceivePop3Apop()));
        }

        // tB[h [MAIL_CONNECTION_TIMEOUT]
        if (bundle.getMailConnectionTimeout() != null && bundle.getMailConnectionTimeout().length() > 0) {
            try {
                result.setMailConnectionTimeout(Integer.parseInt(bundle.getMailConnectionTimeout()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [MAIL_TIMEOUT]
        if (bundle.getMailTimeout() != null && bundle.getMailTimeout().length() > 0) {
            try {
                result.setMailTimeout(Integer.parseInt(bundle.getMailTimeout()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [SESSION_LOG_DIRECTORY_ERROR]
        if (bundle.getSessionLogDirectoryError() != null && bundle.getSessionLogDirectoryError().length() > 0) {
            result.setSessionLogDirectoryError(bundle.getSessionLogDirectoryError());
        }

        // tB[h [SESSION_LOG_DIRECTORY_SUCCESS]
        if (bundle.getSessionLogDirectorySuccess() != null && bundle.getSessionLogDirectorySuccess().length() > 0) {
            result.setSessionLogDirectorySuccess(bundle.getSessionLogDirectorySuccess());
        }

        // tB[h [SESSION_LOG_OUTPUT_WITH_NO_RECEIVE_PROCESS]
        if (bundle.getSessionLogOutputWithNoReceiveProcess() != null && bundle.getSessionLogOutputWithNoReceiveProcess().length() > 0) {
            result.setSessionLogOutputWithNoReceiveProcess("true".equals(bundle.getSessionLogOutputWithNoReceiveProcess()));
        }

        // tB[h [SOCKETFACTORY_CLASS]
        if (bundle.getSocketfactoryClass() != null && bundle.getSocketfactoryClass().length() > 0) {
            result.setSocketfactoryClass(bundle.getSocketfactoryClass());
        }

        // tB[h [SOCKETFACTORY_FALLBACK]
        if (bundle.getSocketfactoryFallback() != null && bundle.getSocketfactoryFallback().length() > 0) {
            result.setSocketfactoryFallback("true".equals(bundle.getSocketfactoryFallback()));
        }

        // tB[h [TEST_MODE]
        if (bundle.getTestMode() != null && bundle.getTestMode().length() > 0) {
            result.setTestMode("true".equals(bundle.getTestMode()));
        }

        // tB[h [TEST_MODE_LOG_DIRECTORY_SEND]
        if (bundle.getTestModeLogDirectorySend() != null && bundle.getTestModeLogDirectorySend().length() > 0) {
            result.setTestModeLogDirectorySend(bundle.getTestModeLogDirectorySend());
        }

        // tB[h [TEST_MODE_LOG_DIRECTORY_RECEIVE]
        if (bundle.getTestModeLogDirectoryReceive() != null && bundle.getTestModeLogDirectoryReceive().length() > 0) {
            result.setTestModeLogDirectoryReceive(bundle.getTestModeLogDirectoryReceive());
        }

        // tB[h [SEND_MAILER_NAME]
        if (bundle.getSendMailerName() != null && bundle.getSendMailerName().length() > 0) {
            result.setSendMailerName(bundle.getSendMailerName());
        }

        // tB[h [SEND_ENCODING]
        if (bundle.getSendEncoding() != null && bundle.getSendEncoding().length() > 0) {
            result.setSendEncoding(bundle.getSendEncoding());
        }

        // tB[h [SEND_ENCODING_NORMALIZE_UNICODE]
        if (bundle.getSendEncodingNormalizeUnicode() != null && bundle.getSendEncodingNormalizeUnicode().length() > 0) {
            result.setSendEncodingNormalizeUnicode("true".equals(bundle.getSendEncodingNormalizeUnicode()));
        }

        // tB[h [SEND_FORTH_CONTENT_TRANSFER_ENCODING_7BIT]
        if (bundle.getSendForthContentTransferEncoding7bit() != null && bundle.getSendForthContentTransferEncoding7bit().length() > 0) {
            result.setSendForthContentTransferEncoding7bit("true".equals(bundle.getSendForthContentTransferEncoding7bit()));
        }

        // tB[h [SEND_FORTH_NEWLINE_AFTER_MESSAGE_TEXT]
        if (bundle.getSendForthNewlineAfterMessageText() != null && bundle.getSendForthNewlineAfterMessageText().length() > 0) {
            result.setSendForthNewlineAfterMessageText("true".equals(bundle.getSendForthNewlineAfterMessageText()));
        }

        // tB[h [SEND_USE_FROM_ADDRESS_AS_MESSAGE_ID]
        if (bundle.getSendUseFromAddressAsMessageId() != null && bundle.getSendUseFromAddressAsMessageId().length() > 0) {
            result.setSendUseFromAddressAsMessageId("true".equals(bundle.getSendUseFromAddressAsMessageId()));
        }

        // tB[h [SEND_MAX_RECIPIENT_ADDR_TO]
        if (bundle.getSendMaxRecipientAddrTo() != null && bundle.getSendMaxRecipientAddrTo().length() > 0) {
            try {
                result.setSendMaxRecipientAddrTo(Integer.parseInt(bundle.getSendMaxRecipientAddrTo()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [SEND_MAX_RECIPIENT_ADDR_CC]
        if (bundle.getSendMaxRecipientAddrCc() != null && bundle.getSendMaxRecipientAddrCc().length() > 0) {
            try {
                result.setSendMaxRecipientAddrCc(Integer.parseInt(bundle.getSendMaxRecipientAddrCc()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [SEND_MAX_TOTAL_ATTACHMENT_SIZE]
        if (bundle.getSendMaxTotalAttachmentSize() != null && bundle.getSendMaxTotalAttachmentSize().length() > 0) {
            try {
                result.setSendMaxTotalAttachmentSize(Integer.parseInt(bundle.getSendMaxTotalAttachmentSize()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [RECEIVE_MAX_MESSAGE_SIZE]
        if (bundle.getReceiveMaxMessageSize() != null && bundle.getReceiveMaxMessageSize().length() > 0) {
            try {
                result.setReceiveMaxMessageSize(Integer.parseInt(bundle.getReceiveMaxMessageSize()));
            } catch (NumberFormatException e) {
                // ܂B
            }
        }

        // tB[h [RECEIVE_FILTER_BY_SUBJECT]
        if (bundle.getReceiveFilterBySubject() != null && bundle.getReceiveFilterBySubject().length() > 0) {
            result.setReceiveFilterBySubject(bundle.getReceiveFilterBySubject());
        }

        return result;
    }
}
